@@ -15,19 +15,22 @@
 //
 // Copyright (C) 2005 Dan Sheridan <dan.sheridan@postman.org.uk>
 // Copyright (C) 2005 Brad Hards <bradh@frogmouth.net>
-// Copyright (C) 2006, 2008, 2010, 2012-2014, 2016-2020 Albert Astals Cid <aacid@kde.org>
+// Copyright (C) 2006, 2008, 2010, 2012-2014, 2016-2021 Albert Astals Cid <aacid@kde.org>
 // Copyright (C) 2007-2008 Julien Rebetez <julienr@svn.gnome.org>
 // Copyright (C) 2007 Carlos Garcia Campos <carlosgc@gnome.org>
 // Copyright (C) 2009, 2010 Ilya Gorenbein <igorenbein@finjan.com>
 // Copyright (C) 2010 Hib Eris <hib@hiberis.nl>
 // Copyright (C) 2012, 2013, 2016 Thomas Freitag <Thomas.Freitag@kabelmail.de>
 // Copyright (C) 2012, 2013 Fabio D'Urso <fabiodurso@hotmail.it>
-// Copyright (C) 2013, 2014, 2017 Adrian Johnson <ajohnson@redneon.com>
+// Copyright (C) 2013, 2014, 2017, 2019 Adrian Johnson <ajohnson@redneon.com>
 // Copyright (C) 2013 Pino Toscano <pino@kde.org>
 // Copyright (C) 2016 Jakub Alba <jakubalba@gmail.com>
 // Copyright (C) 2018, 2019 Adam Reichold <adam.reichold@t-online.de>
 // Copyright (C) 2018 Tobias Deiminger <haxtibal@posteo.de>
 // Copyright (C) 2019 LE GARREC Vincent <legarrec.vincent@gmail.com>
+// Copyright (C) 2020 Klarälvdalens Datakonsult AB, a KDAB Group company, <info@kdab.com>. Work sponsored by Technische Universität Dresden
+// Copyright (C) 2010 William Bader <william@newspapersystems.com>
+// Copyright (C) 2021 Mahmoud Khalil <mahmoudkhalil11@gmail.com>
 //
 // To see a description of the changes please see the Changelog file that
 // came with your tarball or type make ChangeLog if you are building from git
@@ -44,6 +47,7 @@
 #include <cctype>
 #include <climits>
 #include <cfloat>
+#include <limits>
 #include "goo/gfile.h"
 #include "goo/gmem.h"
 #include "Object.h"
@@ -255,12 +259,14 @@ XRef::XRef(const Object *trailerDictA) : XRef {}
         trailerDict = trailerDictA->copy();
 }
 
-XRef::XRef(BaseStream *strA, Goffset pos, Goffset mainXRefEntriesOffsetA, bool *wasReconstructed, bool reconstruct) : XRef {}
+XRef::XRef(BaseStream *strA, Goffset pos, Goffset mainXRefEntriesOffsetA, bool *wasReconstructed, bool reconstruct, const std::function<void()> &xrefReconstructedCallback) : XRef {}
 {
     Object obj;
 
     mainXRefEntriesOffset = mainXRefEntriesOffsetA;
 
+    xrefReconstructedCb = xrefReconstructedCallback;
+
     // read the trailer
     str = strA;
     start = str->getStart();
@@ -328,6 +334,10 @@ XRef::XRef(BaseStream *strA, Goffset pos, Goffset mainXRefEntriesOffsetA, bool *
 XRef::~XRef()
 {
     for (int i = 0; i < size; i++) {
+        if (entries[i].type == xrefEntryFree) {
+            continue;
+        }
+
         entries[i].obj.~Object();
     }
     gfree(entries);
@@ -456,13 +466,18 @@ bool XRef::readXRef(Goffset *pos, std::vector<Goffset> *followedXRefStm, std::ve
     Object obj;
     bool more;
 
-    if (unlikely(start > (LLONG_MAX - *pos))) {
+    Goffset parsePos;
+    if (unlikely(checkedAdd(start, *pos, &parsePos))) {
+        ok = false;
+        return false;
+    }
+    if (parsePos < 0) {
         ok = false;
         return false;
     }
 
     // start up a parser, parse one token
-    parser = new Parser(nullptr, str->makeSubStream(start + *pos, false, 0, Object(objNull)), true);
+    parser = new Parser(nullptr, str->makeSubStream(parsePos, false, 0, Object(objNull)), true);
     obj = parser->getObj(true);
 
     // parse an old-style xref table
@@ -788,8 +803,13 @@ bool XRef::readXRefStreamSection(Stream *xrefStr, const int *w, int first, int n
             gen = (gen << 8) + c;
         }
         if (gen > INT_MAX) {
-            error(errSyntaxError, -1, "Gen inside xref table too large (bigger than INT_MAX)");
-            return false;
+            if (i == 0 && gen == std::numeric_limits<uint32_t>::max()) {
+                // workaround broken generators
+                gen = 65535;
+            } else {
+                error(errSyntaxError, -1, "Gen inside xref table too large (bigger than INT_MAX)");
+                return false;
+            }
         }
         if (entries[i].offset == -1) {
             switch (type) {
@@ -847,6 +867,10 @@ bool XRef::constructXRef(bool *wasReconstructed, bool needCatalogDict)
         *wasReconstructed = true;
     }
 
+    if (xrefReconstructedCb) {
+        xrefReconstructedCb();
+    }
+
     str->reset();
     while (true) {
         pos = str->getPos();
@@ -1114,7 +1138,7 @@ Object XRef::fetch(const Ref ref, int recursion)
     return fetch(ref.num, ref.gen, recursion);
 }
 
-Object XRef::fetch(int num, int gen, int recursion)
+Object XRef::fetch(int num, int gen, int recursion, Goffset *endPos)
 {
     XRefEntry *e;
     Object obj1, obj2, obj3;
@@ -1151,6 +1175,9 @@ Object XRef::fetch(int num, int gen, int recursion)
                     if (longNumber <= INT_MAX && longNumber >= INT_MIN && *end_ptr == '\0') {
                         int number = longNumber;
                         error(errSyntaxWarning, -1, "Cmd was not obj but {0:s}, assuming the creator meant obj {1:d}", cmd, number);
+                        if (endPos) {
+                            *endPos = parser.getPos();
+                        }
                         return Object(number);
                     }
                 }
@@ -1158,6 +1185,9 @@ Object XRef::fetch(int num, int gen, int recursion)
             goto err;
         }
         Object obj = parser.getObj(false, (encrypted && !e->getFlag(XRefEntry::Unencrypted)) ? fileKey : nullptr, encAlgorithm, keyLength, num, gen, recursion);
+        if (endPos) {
+            *endPos = parser.getPos();
+        }
         return obj;
     }
 
@@ -1185,6 +1215,9 @@ Object XRef::fetch(int num, int gen, int recursion)
                 objStrs.put(e->offset, objStr);
             }
         }
+        if (endPos) {
+            *endPos = -1;
+        }
         return objStr->getObject(e->gen, num);
     }
 
@@ -1194,10 +1227,28 @@ Object XRef::fetch(int num, int gen, int recursion)
 
 err:
     if (!xRefStream && !xrefReconstructed) {
+        // Check if there has been any updated object, if there has been we can't reconstruct because that would mean losing the changes
+        bool xrefHasChanges = false;
+        for (int i = 0; i < size; i++) {
+            if (entries[i].getFlag(XRefEntry::Updated)) {
+                xrefHasChanges = true;
+                break;
+            }
+        }
+        if (xrefHasChanges) {
+            error(errInternal, -1, "xref num {0:d} not found but needed, document has changes, reconstruct aborted\n", num);
+            // pretend we constructed the xref, otherwise we will do this check again and again
+            xrefReconstructed = true;
+            return Object(objNull);
+        }
+
         error(errInternal, -1, "xref num {0:d} not found but needed, try to reconstruct\n", num);
         rootNum = -1;
         constructXRef(&xrefReconstructed);
-        return fetch(num, gen, ++recursion);
+        return fetch(num, gen, ++recursion, endPos);
+    }
+    if (endPos) {
+        *endPos = -1;
     }
     return Object(objNull);
 }
